@@ -17,7 +17,6 @@ import os
 import tempfile
 
 import mock
-from oslo_serialization import jsonutils
 import six
 
 from novaclient import api_versions
@@ -38,7 +37,7 @@ class ServersTest(utils.FixturedTestCase):
 
     def setUp(self):
         super(ServersTest, self).setUp()
-        self.useFixture(floatingips.FloatingFixture(self.requests))
+        self.useFixture(floatingips.FloatingFixture(self.requests_mock))
         if self.api_version:
             self.cs.api_version = api_versions.APIVersion(self.api_version)
 
@@ -68,8 +67,8 @@ class ServersTest(utils.FixturedTestCase):
 
         self.assertEqual(2, len(sl))
 
-        self.assertEqual(self.requests.request_history[-2].method, 'GET')
-        self.assertEqual(self.requests.request_history[-2].path_url,
+        self.assertEqual(self.requests_mock.request_history[-2].method, 'GET')
+        self.assertEqual(self.requests_mock.request_history[-2].path_url,
                          '/servers/detail?marker=1234')
         self.assert_called('GET', '/servers/detail?marker=5678')
 
@@ -320,7 +319,7 @@ class ServersTest(utils.FixturedTestCase):
         self.assert_request_id(s, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers')
         self.assertIsInstance(s, servers.Server)
-        body = jsonutils.loads(self.requests.last_request.body)
+        body = self.requests_mock.last_request.json()
         self.assertEqual(test_password, body['server']['adminPass'])
 
     def test_create_server_userdata_bin(self):
@@ -346,7 +345,7 @@ class ServersTest(utils.FixturedTestCase):
             self.assert_called('POST', '/servers')
             self.assertIsInstance(s, servers.Server)
             # verify userdata matches original
-            body = jsonutils.loads(self.requests.last_request.body)
+            body = self.requests_mock.last_request.json()
             transferred_data = body['server']['user_data']
             transferred_data = base64.b64decode(transferred_data)
             self.assertEqual(original_data, transferred_data)
@@ -364,8 +363,7 @@ class ServersTest(utils.FixturedTestCase):
         self.assertIsInstance(s, servers.Server)
 
         # verify disk config param was used in the request:
-        body = jsonutils.loads(self.requests.last_request.body)
-        server = body['server']
+        server = self.requests_mock.last_request.json()['server']
         self.assertIn('OS-DCF:diskConfig', server)
         self.assertEqual(disk_config, server['OS-DCF:diskConfig'])
 
@@ -471,9 +469,7 @@ class ServersTest(utils.FixturedTestCase):
         self.assert_called('POST', '/servers/1234/action')
 
         # verify disk config param was used in the request:
-        body = jsonutils.loads(self.requests.last_request.body)
-
-        d = body[operation]
+        d = self.requests_mock.last_request.json()[operation]
         self.assertIn('OS-DCF:diskConfig', d)
         self.assertEqual(disk_config, d['OS-DCF:diskConfig'])
 
@@ -488,8 +484,7 @@ class ServersTest(utils.FixturedTestCase):
         ret = s.rebuild(image=1, preserve_ephemeral=True)
         self.assert_request_id(ret, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/action')
-        body = jsonutils.loads(self.requests.last_request.body)
-        d = body['rebuild']
+        d = self.requests_mock.last_request.json()['rebuild']
         self.assertIn('preserve_ephemeral', d)
         self.assertTrue(d['preserve_ephemeral'])
 
@@ -498,8 +493,7 @@ class ServersTest(utils.FixturedTestCase):
         s = self.cs.servers.get(1234)
         ret = s.rebuild(image=1, name='new', meta={'foo': 'bar'}, files=files)
         self.assert_request_id(ret, fakes.FAKE_REQUEST_ID_LIST)
-        body = jsonutils.loads(self.requests.last_request.body)
-        d = body['rebuild']
+        d = self.requests_mock.last_request.json()['rebuild']
         self.assertEqual('new', d['name'])
         self.assertEqual({'foo': 'bar'}, d['metadata'])
         self.assertEqual('/etc/passwd',
@@ -800,44 +794,59 @@ class ServersTest(utils.FixturedTestCase):
 
     def test_get_vnc_console(self):
         s = self.cs.servers.get(1234)
-        vc = s.get_vnc_console('fake')
+        vc = s.get_vnc_console('novnc')
         self.assert_request_id(vc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/action')
 
-        vc = self.cs.servers.get_vnc_console(s, 'fake')
+        vc = self.cs.servers.get_vnc_console(s, 'novnc')
         self.assert_request_id(vc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/action')
 
     def test_get_spice_console(self):
         s = self.cs.servers.get(1234)
-        sc = s.get_spice_console('fake')
+        sc = s.get_spice_console('spice-html5')
         self.assert_request_id(sc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/action')
 
-        sc = self.cs.servers.get_spice_console(s, 'fake')
+        sc = self.cs.servers.get_spice_console(s, 'spice-html5')
         self.assert_request_id(sc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/action')
 
     def test_get_serial_console(self):
         s = self.cs.servers.get(1234)
-        sc = s.get_serial_console('fake')
+        sc = s.get_serial_console('serial')
         self.assert_request_id(sc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/action')
 
-        sc = self.cs.servers.get_serial_console(s, 'fake')
+        sc = self.cs.servers.get_serial_console(s, 'serial')
         self.assert_request_id(sc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/action')
 
     def test_get_rdp_console(self):
         s = self.cs.servers.get(1234)
-        rc = s.get_rdp_console('fake')
+        rc = s.get_rdp_console('rdp-html5')
         self.assert_request_id(rc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/action')
 
-        rc = self.cs.servers.get_rdp_console(s, 'fake')
+        rc = self.cs.servers.get_rdp_console(s, 'rdp-html5')
         self.assert_request_id(rc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/action')
 
+    def test_get_console_url(self):
+        s = self.cs.servers.get(1234)
+        rc = s.get_console_url('novnc')
+        self.assert_request_id(rc, fakes.FAKE_REQUEST_ID_LIST)
+        self.assert_called('POST', '/servers/1234/action')
+
+        rc = self.cs.servers.get_console_url(s, 'novnc')
+        self.assert_request_id(rc, fakes.FAKE_REQUEST_ID_LIST)
+        self.assert_called('POST', '/servers/1234/action')
+
+        # test the case with invalid console type
+        self.assertRaises(exceptions.UnsupportedConsoleType,
+                          s.get_console_url,
+                          'invalid')
+
     def test_create_image(self):
         s = self.cs.servers.get(1234)
         im = s.create_image('123')
@@ -1007,44 +1016,83 @@ class ServersV26Test(ServersTest):
 
     def test_get_vnc_console(self):
         s = self.cs.servers.get(1234)
-        vc = s.get_vnc_console('fake')
+        vc = s.get_vnc_console('novnc')
         self.assert_request_id(vc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/remote-consoles')
 
-        vc = self.cs.servers.get_vnc_console(s, 'fake')
+        vc = self.cs.servers.get_vnc_console(s, 'novnc')
         self.assert_request_id(vc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/remote-consoles')
 
+        # test the case with invalid console type
+        self.assertRaises(exceptions.UnsupportedConsoleType,
+                          s.get_vnc_console,
+                          'invalid')
+
     def test_get_spice_console(self):
         s = self.cs.servers.get(1234)
-        sc = s.get_spice_console('fake')
+        sc = s.get_spice_console('spice-html5')
         self.assert_request_id(sc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/remote-consoles')
 
-        sc = self.cs.servers.get_spice_console(s, 'fake')
+        sc = self.cs.servers.get_spice_console(s, 'spice-html5')
         self.assert_request_id(sc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/remote-consoles')
 
+        # test the case with invalid console type
+        self.assertRaises(exceptions.UnsupportedConsoleType,
+                          s.get_spice_console,
+                          'invalid')
+
     def test_get_serial_console(self):
         s = self.cs.servers.get(1234)
-        sc = s.get_serial_console('fake')
+        sc = s.get_serial_console('serial')
         self.assert_request_id(sc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/remote-consoles')
 
-        sc = self.cs.servers.get_serial_console(s, 'fake')
+        sc = self.cs.servers.get_serial_console(s, 'serial')
         self.assert_request_id(sc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/remote-consoles')
 
+        # test the case with invalid console type
+        self.assertRaises(exceptions.UnsupportedConsoleType,
+                          s.get_serial_console,
+                          'invalid')
+
     def test_get_rdp_console(self):
         s = self.cs.servers.get(1234)
-        rc = s.get_rdp_console('fake')
+        rc = s.get_rdp_console('rdp-html5')
         self.assert_request_id(rc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/remote-consoles')
 
-        rc = self.cs.servers.get_rdp_console(s, 'fake')
+        rc = self.cs.servers.get_rdp_console(s, 'rdp-html5')
         self.assert_request_id(rc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/remote-consoles')
 
+        # test the case with invalid console type
+        self.assertRaises(exceptions.UnsupportedConsoleType,
+                          s.get_rdp_console,
+                          'invalid')
+
+    def test_get_console_url(self):
+        s = self.cs.servers.get(1234)
+        vc = s.get_console_url('novnc')
+        self.assert_request_id(vc, fakes.FAKE_REQUEST_ID_LIST)
+        self.assert_called('POST', '/servers/1234/remote-consoles')
+
+        vc = self.cs.servers.get_console_url(s, 'novnc')
+        self.assert_request_id(vc, fakes.FAKE_REQUEST_ID_LIST)
+        self.assert_called('POST', '/servers/1234/remote-consoles')
+
+        # test the case with invalid console type
+        self.assertRaises(exceptions.UnsupportedConsoleType,
+                          s.get_console_url,
+                          'invalid')
+        # console type webmks is supported since api version 2.8
+        self.assertRaises(exceptions.UnsupportedConsoleType,
+                          s.get_console_url,
+                          'webmks')
+
 
 class ServersV28Test(ServersV26Test):
 
@@ -1060,6 +1108,21 @@ class ServersV28Test(ServersV26Test):
         self.assert_request_id(mksc, fakes.FAKE_REQUEST_ID_LIST)
         self.assert_called('POST', '/servers/1234/remote-consoles')
 
+    def test_get_console_url(self):
+        s = self.cs.servers.get(1234)
+        mksc = s.get_console_url('novnc')
+        self.assert_request_id(mksc, fakes.FAKE_REQUEST_ID_LIST)
+        self.assert_called('POST', '/servers/1234/remote-consoles')
+
+        mksc = self.cs.servers.get_console_url(s, 'novnc')
+        self.assert_request_id(mksc, fakes.FAKE_REQUEST_ID_LIST)
+        self.assert_called('POST', '/servers/1234/remote-consoles')
+
+        # test the case with invalid console type
+        self.assertRaises(exceptions.UnsupportedConsoleType,
+                          s.get_console_url,
+                          'invalid')
+
 
 class ServersV214Test(ServersV28Test):
 
